==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-knownerror-mgmt/dictionaries/sk.dict.itop-knownerror-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2023 Combodo SARL
 * @license	http://opensource.org/licenses/AGPL-3.0
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with iTop. If not, see <http://www.gnu.org/licenses/>
 */
// Dictionnay conventions
// Class:<class_name>
// Class:<class_name>+
// Class:<class_name>/Attribute:<attribute_code>
// Class:<class_name>/Attribute:<attribute_code>+
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>+
// Class:<class_name>/Stimulus:<stimulus_code>
// Class:<class_name>/Stimulus:<stimulus_code>+
//////////////////////////////////////////////////////////////////////
// Classes in 'bizmodel'
//////////////////////////////////////////////////////////////////////
//
// Dictionnay conventions
// Class:<class_name>
// Class:<class_name>+
// Class:<class_name>/Attribute:<attribute_code>
// Class:<class_name>/Attribute:<attribute_code>+
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>
// Class:<class_name>/Attribute:<attribute_code>/Value:<value>+
// Class:<class_name>/Stimulus:<stimulus_code>
// Class:<class_name>/Stimulus:<stimulus_code>+
//
// Class: KnownError
//
Dict::Add('SK SK', 'Slovak', 'Slovenčina', array(
	'Class:KnownError' => 'Known Error~~',
	'Class:KnownError+' => 'Error documented for a known issue~~',
	'Class:KnownError/Attribute:name' => 'Name~~',
	'Class:KnownError/Attribute:name+' => '~~',
	'Class:KnownError/Attribute:org_id' => 'Customer~~',
	'Class:KnownError/Attribute:org_id+' => '~~',
	'Class:KnownError/Attribute:cust_name' => 'Customer Name~~',
	'Class:KnownError/Attribute:cust_name+' => '~~',
	'Class:KnownError/Attribute:problem_id' => 'Related Problem~~',
	'Class:KnownError/Attribute:problem_id+' => '~~',
	'Class:KnownError/Attribute:problem_ref' => 'Related Problem Ref~~',
	'Class:KnownError/Attribute:problem_ref+' => '~~',
	'Class:KnownError/Attribute:symptom' => 'Symptom~~',
	'Class:KnownError/Attribute:symptom+' => '~~',
	'Class:KnownError/Attribute:root_cause' => 'Root Cause~~',
	'Class:KnownError/Attribute:root_cause+' => '~~',
	'Class:KnownError/Attribute:workaround' => 'Work around~~',
	'Class:KnownError/Attribute:workaround+' => '~~',
	'Class:KnownError/Attribute:solution' => 'Solution~~',
	'Class:KnownError/Attribute:solution+' => '~~',
	'Class:KnownError/Attribute:error_code' => 'Error Code~~',
	'Class:KnownError/Attribute:error_code+' => '~~',
	'Class:KnownError/Attribute:domain' => 'Domain~~',
	'Class:KnownError/Attribute:domain+' => '~~',
	'Class:KnownError/Attribute:domain/Value:Application' => 'Application~~',
	'Class:KnownError/Attribute:domain/Value:Application+' => 'Application~~',
	'Class:KnownError/Attribute:domain/Value:Desktop' => 'Desktop~~',
	'Class:KnownError/Attribute:domain/Value:Desktop+' => 'Desktop~~',
	'Class:KnownError/Attribute:domain/Value:Network' => 'Network~~',
	'Class:KnownError/Attribute:domain/Value:Network+' => 'Network~~',
	'Class:KnownError/Attribute:domain/Value:Server' => 'Server~~',
	'Class:KnownError/Attribute:domain/Value:Server+' => 'Server~~',
	'Class:KnownError/Attribute:vendor' => 'Vendor~~',
	'Class:KnownError/Attribute:vendor+' => '~~',
	'Class:KnownError/Attribute:model' => 'Model~~',
	'Class:KnownError/Attribute:model+' => '~~',
	'Class:KnownError/Attribute:version' => 'Version~~',
	'Class:KnownError/Attribute:version+' => '~~',
	'Class:KnownError/Attribute:ci_list' => 'CIs~~',
	'Class:KnownError/Attribute:ci_list+' => 'All the configuration items that are related to this known error~~',
	'Class:KnownError/Attribute:document_list' => 'Documents~~',
	'Class:KnownError/Attribute:document_list+' => 'All the documents linked to this known error~~',
));

//
// Class: lnkErrorToFunctionalCI
//

Dict::Add('SK SK', 'Slovak', 'Slovenčina', array(
	'Class:lnkErrorToFunctionalCI' => 'Link Error / FunctionalCI~~',
	'Class:lnkErrorToFunctionalCI+' => 'Infra related to a known error~~',
	'Class:lnkErrorToFunctionalCI/Name' => '%1$s / %2$s~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id' => 'CI~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name' => 'CI name~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id' => 'Error~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name' => 'Error name~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:reason' => 'Reason~~',
	'Class:lnkErrorToFunctionalCI/Attribute:reason+' => '~~',
));

//
// Class: lnkDocumentToError
//

Dict::Add('SK SK', 'Slovak', 'Slovenčina', array(
	'Class:lnkDocumentToError' => 'Link Documents / Errors~~',
	'Class:lnkDocumentToError+' => 'A link between a document and a known error~~',
	'Class:lnkDocumentToError/Name' => '%1$s / %2$s~~',
	'Class:lnkDocumentToError/Attribute:document_id' => 'Document~~',
	'Class:lnkDocumentToError/Attribute:document_id+' => '~~',
	'Class:lnkDocumentToError/Attribute:document_name' => 'Document Name~~',
	'Class:lnkDocumentToError/Attribute:document_name+' => '~~',
	'Class:lnkDocumentToError/Attribute:error_id' => 'Error~~',
	'Class:lnkDocumentToError/Attribute:error_id+' => '~~',
	'Class:lnkDocumentToError/Attribute:error_name' => 'Error name~~',
	'Class:lnkDocumentToError/Attribute:error_name+' => '~~',
	'Class:lnkDocumentToError/Attribute:link_type' => 'link_type~~',
	'Class:lnkDocumentToError/Attribute:link_type+' => '~~',
));

Dict::Add('SK SK', 'Slovak', 'Slovenčina', array(
	'Menu:ProblemManagement' => 'Problem Management~~',
	'Menu:ProblemManagement+' => 'Problem Management~~',
	'Menu:Problem:Shortcuts' => 'Shortcuts~~',
	'Menu:NewError' => 'New known error~~',
	'Menu:NewError+' => 'Creation of a new known error~~',
	'Menu:SearchError' => 'Search for known errors~~',
	'Menu:SearchError+' => 'Search for known errors~~',
	'Menu:Problem:KnownErrors' => 'All known errors~~',
	'Menu:Problem:KnownErrors+' => 'All known errors~~',
));

==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-knownerror-mgmt/dictionaries/sk.dict.itop-knownerror-mgmt.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 *
 */
Dict::Add('SK SK', 'Slovak', 'Slovenčina', [
	'Class:KnownError' => 'Known Error~~',
	'Class:KnownError+' => 'Error documented for a known issue~~',
	'Class:KnownError/Attribute:ci_list' => 'CIs~~',
	'Class:KnownError/Attribute:ci_list+' => 'All the configuration items that are related to this known error~~',
	'Class:KnownError/Attribute:cust_name' => 'Customer Name~~',
	'Class:KnownError/Attribute:cust_name+' => '~~',
	'Class:KnownError/Attribute:document_list' => 'Documents~~',
	'Class:KnownError/Attribute:document_list+' => 'All the documents linked to this known error~~',
	'Class:KnownError/Attribute:domain' => 'Domain~~',
	'Class:KnownError/Attribute:domain+' => '~~',
	'Class:KnownError/Attribute:domain/Value:Application' => 'Application~~',
	'Class:KnownError/Attribute:domain/Value:Application+' => 'Application~~',
	'Class:KnownError/Attribute:domain/Value:Desktop' => 'Desktop~~',
	'Class:KnownError/Attribute:domain/Value:Desktop+' => 'Desktop~~',
	'Class:KnownError/Attribute:domain/Value:Network' => 'Network~~',
	'Class:KnownError/Attribute:domain/Value:Network+' => 'Network~~',
	'Class:KnownError/Attribute:domain/Value:Server' => 'Server~~',
	'Class:KnownError/Attribute:domain/Value:Server+' => 'Server~~',
	'Class:KnownError/Attribute:error_code' => 'Error Code~~',
	'Class:KnownError/Attribute:error_code+' => '~~',
	'Class:KnownError/Attribute:model' => 'Model~~',
	'Class:KnownError/Attribute:model+' => '~~',
	'Class:KnownError/Attribute:name' => 'Name~~',
	'Class:KnownError/Attribute:name+' => '~~',
	'Class:KnownError/Attribute:org_id' => 'Customer~~',
	'Class:KnownError/Attribute:org_id+' => '~~',
	'Class:KnownError/Attribute:problem_id' => 'Related Problem~~',
	'Class:KnownError/Attribute:problem_id+' => '~~',
	'Class:KnownError/Attribute:problem_ref' => 'Related Problem Ref~~',
	'Class:KnownError/Attribute:problem_ref+' => '~~',
	'Class:KnownError/Attribute:root_cause' => 'Root Cause~~',
	'Class:KnownError/Attribute:root_cause+' => '~~',
	'Class:KnownError/Attribute:solution' => 'Solution~~',
	'Class:KnownError/Attribute:solution+' => '~~',
	'Class:KnownError/Attribute:symptom' => 'Symptom~~',
	'Class:KnownError/Attribute:symptom+' => '~~',
	'Class:KnownError/Attribute:vendor' => 'Vendor~~',
	'Class:KnownError/Attribute:vendor+' => '~~',
	'Class:KnownError/Attribute:version' => 'Version~~',
	'Class:KnownError/Attribute:version+' => '~~',
	'Class:KnownError/Attribute:workaround' => 'Work around~~',
	'Class:KnownError/Attribute:workaround+' => '~~',
	'Class:lnkDocumentToError' => 'Link Documents / Errors~~',
	'Class:lnkDocumentToError+' => 'A link between a document and a known error~~',
	'Class:lnkDocumentToError/Attribute:document_id' => 'Document~~',
	'Class:lnkDocumentToError/Attribute:document_id+' => '~~',
	'Class:lnkDocumentToError/Attribute:document_name' => 'Document Name~~',
	'Class:lnkDocumentToError/Attribute:document_name+' => '~~',
	'Class:lnkDocumentToError/Attribute:error_id' => 'Error~~',
	'Class:lnkDocumentToError/Attribute:error_id+' => '~~',
	'Class:lnkDocumentToError/Attribute:error_name' => 'Error name~~',
	'Class:lnkDocumentToError/Attribute:error_name+' => '~~',
	'Class:lnkDocumentToError/Attribute:link_type' => 'link_type~~',
	'Class:lnkDocumentToError/Attribute:link_type+' => '~~',
	'Class:lnkDocumentToError/Name' => '%1$s / %2$s~~',
	'Class:lnkErrorToFunctionalCI' => 'Link Error / FunctionalCI~~',
	'Class:lnkErrorToFunctionalCI+' => 'Infra related to a known error~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id' => 'Error~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_id+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name' => 'Error name~~',
	'Class:lnkErrorToFunctionalCI/Attribute:error_name+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id' => 'CI~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_id+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name' => 'CI name~~',
	'Class:lnkErrorToFunctionalCI/Attribute:functionalci_name+' => '~~',
	'Class:lnkErrorToFunctionalCI/Attribute:reason' => 'Reason~~',
	'Class:lnkErrorToFunctionalCI/Attribute:reason+' => '~~',
	'Class:lnkErrorToFunctionalCI/Name' => '%1$s / %2$s~~',
	'Menu:NewError' => 'New known error~~',
	'Menu:NewError+' => 'Creation of a new known error~~',
	'Menu:Problem:KnownErrors' => 'All known errors~~',
	'Menu:Problem:KnownErrors+' => 'All known errors~~',
	'Menu:Problem:Shortcuts' => 'Shortcuts~~',
	'Menu:ProblemManagement' => 'Problem Management~~',
	'Menu:ProblemManagement+' => 'Problem Management~~',
	'Menu:SearchError' => 'Search for known errors~~',
	'Menu:SearchError+' => 'Search for known errors~~',
]);
